@@ -10,11 +10,12 @@
 #' @examples
 #' NA
 #' 
-server <- function(input, output, session) {
-  isWebServer <- Sys.getenv("SHINY_ENV", "development") == "production"
-  maxRequestSize <- if (isWebServer) 250*1024^2 else 1000000*1024^2
+server = function(input, output, session) {
+  isWebServer = Sys.getenv("SHINY_ENV", "development") == "production"
+  maxRequestSize = if (isWebServer) 250*1024^2 else 1000000*1024^2
   options(shiny.maxRequestSize=maxRequestSize)
   session$allowReconnect(TRUE)
+  
   observe({
     toggleClass(condition = TRUE,
                 class = "disabled",
@@ -25,43 +26,51 @@ server <- function(input, output, session) {
     updateTabsetPanel(session = session, inputId = "tablist", 
                       selected = "Future")
   })
+  
   observeEvent(input$"home-StartPipeline", {
     updateTabsetPanel(session = session, inputId = "tablist", 
                       selected = "Uploaddata")
   })
   
-  loadpage_values <- loadpageServer("loadpage", parent_session = session)
+  loadpage_values = loadpageServer("loadpage", parent_session = session, is_web_server = isWebServer)
   loadpage_input = loadpage_values$input
   get_data = loadpage_values$getData
   
-  qc_values <- callModule(qcServer, "qc",session, reactive(loadpage_input),get_data)
+  # qcServer - update to direct call if refactored, otherwise keep callModule for now
+  qc_values = callModule(qcServer, "qc", session, reactive(loadpage_input), get_data)
   qc_input = qc_values$input
   preprocess_data = qc_values$preprocessData
-  
-  statmodel_values <- callModule(statmodelServer, "statmodel",session, 
-                                reactive(loadpage_input),reactive(qc_input),get_data,preprocess_data)
+
+  statmodel_values = statmodelServer(
+    id = "statmodel",
+    parent_session = session,
+    loadpage_input = reactive(loadpage_input),
+    qc_input = reactive(qc_input),
+    get_data = get_data,
+    preprocess_data = preprocess_data
+  )
   statmodel_input = statmodel_values$input
   data_comparison = statmodel_values$dataComparison
   
-  callModule(expdesServer, "expdes",session, reactive(loadpage_input),
-             reactive(qc_input),reactive(statmodel_input),data_comparison)
+  # expdesServer - keep callModule if not yet refactored
+  callModule(expdesServer, "expdes", session, reactive(loadpage_input),
+             reactive(qc_input), reactive(statmodel_input), data_comparison)
+  
   observeEvent(input$proceed, {
     updateTabsetPanel(session = session, inputId = "tablist", 
                       selected = "Uploaddata")
   })
   
+  # visualizeNetworkServer - keep callModule if not yet refactored
   callModule(visualizeNetworkServer, "network", session, data_comparison)
   
-  # statmodel= reactiveFileReader(1000, session, "panels/statmodel-ui.R", source)
-  # output$statmodel = renderUI(statmodel())
-  # 
   observe({
-    if(input$"loadpage-DDA_DIA" %in% c("TMT") && input$"loadpage-BIO" %in% c("PTM") ){
+    if(input$"loadpage-DDA_DIA" %in% c("TMT") && input$"loadpage-BIO" %in% c("PTM")) {
       hideTab(inputId = "tablist", target = "PQ")
       hideTab(inputId = "tablist", target = "Future")
     }
     
-    if(!(input$"loadpage-DDA_DIA" %in% c("TMT")) && !(input$"loadpage-BIO" %in% c("PTM"))){
+    if(!(input$"loadpage-DDA_DIA" %in% c("TMT")) && !(input$"loadpage-BIO" %in% c("PTM"))) {
       showTab(inputId = "tablist", target = "PQ")
       showTab(inputId = "tablist", target = "Future")
     }
