@@ -573,7 +573,8 @@ test_that("dia spectronaut", {
     mock_input$BIO <- "Protein"
     mock_input$DDA_DIA <- "LType"
     mock_input$filetype = "spec"
-    
+    mock_input$q_val = TRUE 
+    mock_input$q_cutoff = 0.01 
     stub(getData,"getAnnot",NULL)
     
     stub(getData,"read.csv",data.table::fread(system.file("tinytest/raw_data/Spectronaut/spectronaut_input.csv",
@@ -991,6 +992,7 @@ test_that("preprocessData QC, PTM and PTMTMT: No", {
     mock_input$filetype = "sample"
     mock_input$norm = "equalizeMedians"
     mock_input$log = "2"
+    mock_input$summaryMethod = "TMP"
 
     stub(preprocessData,"getData",mockGetData(mock_input))
     stub(preprocessData,"loadpage_input",mock_input)
@@ -1021,6 +1023,7 @@ test_that("preprocessData QC, PTM and PTMTMT: Yes", {
     mock_input$norm = "equalizeMedians"
     mock_input$log = "2"
     mock_input$summarization = "msstats"
+    mock_input$summaryMethod = "TMP"
 
     stub(preprocessData,"getData",mockGetData(mock_input))
     stub(preprocessData,"loadpage_input",mock_input)
@@ -1081,6 +1084,7 @@ test_that("preprocessData QC Other", {
     mock_input$filetype = "sample"
     mock_input$norm = "equalizeMedians"
     mock_input$log = "2"
+    mock_input$summaryMethod = "TMP"
 
     stub(preprocessData,"getData",mockGetData(mock_input))
     stub(preprocessData,"loadpage_input",mock_input)
@@ -1214,6 +1218,7 @@ test_that("dataComparison statmodel PTM PTMTMT: No", {
     mock_input$MBi = TRUE
     mock_input$log = "2"
     mock_input$norm = "equalizeMedians"
+    mock_input$summaryMethod = "TMP"
 
     stub(dataComparison,"loadpage_input",mock_input,2)
     stub(dataComparison,"qc_input",mock_input)
@@ -1317,6 +1322,7 @@ test_that("dataComparison statmodel Other", {
     mock_input$filetype = "sample"
     mock_input$norm = "equalizeMedians"
     mock_input$log = "2"
+    mock_input$summaryMethod = "TMP"
 
     stub(dataComparison,"loadpage_input",mock_input,2)
     stub(dataComparison,"qc_input",mock_input)
@@ -1346,3 +1352,178 @@ test_that("dataComparison statmodel Other", {
     expect_identical(names(output), expected_names)
   })
 })
+
+
+################################################################################
+#  getData for Spectronaut FUNCTION TESTING
+################################################################################
+
+describe("getData for Spectronaut input with anomaly scores", {
+  
+  # Dummy data frames
+  dummy_spec_data <- data.frame(FG.Charge = 2, PG.ProteinGroups = "Protein1")
+  dummy_run_order <- data.frame(Run = "Run1", Order = 1)
+  dummy_annot <- data.frame(Run = "Run1", Condition = "A")
+  
+  # A mock converter function
+  mock_spectro_converter <- function(...) {
+    args <- list(...)
+    return(args) # Return the arguments for inspection
+  }
+  
+  test_that("adds anomaly score arguments when checkbox is checked", {
+    
+    #SETUP: Mock Shiny input for the "checked" scenario
+    mock_input_anomaly <- list(
+      BIO = "Protein",
+      DDA_DIA = "DIA",
+      filetype = "spec",
+      specdata = list(datapath = "dummy_spec.csv"),
+      sep_specdata = ",",
+      annot = list(datapath = "dummy_annot.csv"),
+      q_val = TRUE,
+      q_cutoff = 0.01,
+      remove = TRUE,
+      calculate_anomaly_scores = TRUE,
+      run_order_file = list(datapath = "dummy_run_order.csv")
+    )
+    
+    # Mock the functions that getData calls
+    stub(getData, "read.csv", function(path, ...) {
+      if (path == "dummy_run_order.csv") return(dummy_run_order)
+      return(dummy_spec_data)
+    })
+    stub(getData, "getAnnot", dummy_annot)
+    
+    stub(getData, "SpectronauttoMSstatsFormat", mock_spectro_converter)
+    
+    #EXECUTION: function call
+    result_args <- getData(mock_input_anomaly)
+    
+    #ASSERTION: Check if the arguments are correct
+    expect_true(result_args$calculateAnomalyScores)
+    expect_equal(result_args$runOrder, dummy_run_order)
+    expect_equal(result_args$anomalyModelFeatures, c("FG.ShapeQualityScore (MS2)", "FG.ShapeQualityScore (MS1)", "EGDeltaRT"))
+    expect_equal(result_args$n_trees, 100)
+  })
+  
+  test_that("does NOT add anomaly score arguments when checkbox is unchecked", {
+    
+    #SETUP: Mock Shiny input for the "unchecked" scenario
+    mock_input_no_anomaly <- list(
+      BIO = "Protein",
+      DDA_DIA = "DIA",
+      filetype = "spec",
+      specdata = list(datapath = "dummy_spec.csv"),
+      sep_specdata = ",",
+      annot = list(datapath = "dummy_annot.csv"),
+      q_val = TRUE,
+      q_cutoff = 0.01,
+      remove = TRUE,
+      calculate_anomaly_scores = FALSE, # Main difference
+      run_order_file = NULL
+    )
+    
+    stub(getData, "read.csv", dummy_spec_data)
+    stub(getData, "getAnnot", dummy_annot)
+    stub(getData, "SpectronauttoMSstatsFormat", mock_spectro_converter)
+    
+    #EXECUTION
+    result_args <- getData(mock_input_no_anomaly)
+    
+    #ASSERTION: Check that the anomaly arguments are NOT present
+    expect_null(result_args$calculateAnomalyScores)
+    expect_null(result_args$runOrder)
+    expect_null(result_args$anomalyModelFeatures)
+  })
+})
+
+describe("getData for Big Spectronaut", {
+  
+  # Common mock input for big spec
+  mock_input_big <- list(
+    filetype = "spec",
+    big_file_spec = TRUE,
+    big_file_browse = list(files = list("file.csv")),
+    qvalue_cutoff = 0.01,
+    max_feature_count = 20,
+    filter_by_excluded = FALSE,
+    filter_by_identified = FALSE,
+    filter_by_qvalue = TRUE,
+    filter_unique_peptides = TRUE,
+    aggregate_psms = TRUE,
+    filter_few_obs = TRUE,
+    BIO = "Protein",
+    DDA_DIA = "DIA"
+  )
+  
+  # Mock data to return
+  mock_arrow_obj <- list(dummy = "arrow")
+  mock_df <- data.frame(ProteinName = "P1", Intensity = 100)
+  
+  test_that("Valid input returns data", {
+    # Mocks
+    stub(getData, "shinyFiles::getVolumes", function() function() c(root = "/"))
+    stub(getData, "shinyFiles::parseFilePaths", function(...) data.frame(datapath = "test.csv"))
+    stub(getData, "file.exists", TRUE)
+    stub(getData, "MSstatsBig::bigSpectronauttoMSstatsFormat", mock_arrow_obj)
+    stub(getData, "dplyr::collect", mock_df)
+    stub(getData, "showNotification", function(...) NULL)
+    stub(getData, "shinybusy::update_modal_spinner", function(...) NULL)
+    stub(getData, "shinybusy::remove_modal_spinner", function(...) NULL)
+    
+    res <- getData(mock_input_big)
+    expect_equal(res, mock_df)
+  })
+  
+  test_that("Invalid qvalue_cutoff returns NULL", {
+    bad_input <- mock_input_big
+    bad_input$qvalue_cutoff <- 1.5
+    
+    stub(getData, "shinyFiles::getVolumes", function() function() c(root = "/"))
+    stub(getData, "shinyFiles::parseFilePaths", function(...) data.frame(datapath = "test.csv"))
+    stub(getData, "showNotification", function(msg, ...) expect_match(msg, "qvalue_cutoff"))
+    stub(getData, "shinybusy::remove_modal_spinner", function(...) NULL)
+
+    res <- getData(bad_input)
+    expect_null(res)
+  })
+  
+  test_that("Invalid max_feature_count returns NULL", {
+    bad_input <- mock_input_big
+    bad_input$max_feature_count <- 0
+    
+    stub(getData, "shinyFiles::getVolumes", function() function() c(root = "/"))
+    stub(getData, "shinyFiles::parseFilePaths", function(...) data.frame(datapath = "test.csv"))
+    stub(getData, "showNotification", function(msg, ...) expect_match(msg, "max_feature_count"))
+    stub(getData, "shinybusy::remove_modal_spinner", function(...) NULL)
+    
+    res <- getData(bad_input)
+    expect_null(res)
+  })
+  
+  test_that("File not found returns NULL", {
+    stub(getData, "shinyFiles::getVolumes", function() function() c(root = "/"))
+    stub(getData, "shinyFiles::parseFilePaths", function(...) data.frame(datapath = "nonexistent.csv"))
+    stub(getData, "file.exists", FALSE)
+    stub(getData, "showNotification", function(msg, ...) expect_match(msg, "does not exist"))
+    stub(getData, "shinybusy::remove_modal_spinner", function(...) NULL)
+    
+    res <- getData(mock_input_big)
+    expect_null(res)
+  })
+  
+  test_that("Memory error returns NULL", {
+    stub(getData, "shinyFiles::getVolumes", function() function() c(root = "/"))
+    stub(getData, "shinyFiles::parseFilePaths", function(...) data.frame(datapath = "test.csv"))
+    stub(getData, "file.exists", TRUE)
+    stub(getData, "MSstatsBig::bigSpectronauttoMSstatsFormat", mock_arrow_obj)
+    stub(getData, "dplyr::collect", function(...) stop("Memory allocation failed"))
+    stub(getData, "showNotification", function(msg, ...) expect_match(msg, "Memory Error"))
+    stub(getData, "shinybusy::update_modal_spinner", function(...) NULL)
+    stub(getData, "shinybusy::remove_modal_spinner", function(...) NULL)
+    
+    res <- getData(mock_input_big)
+    expect_null(res)
+  })
+})
